@@ -7,9 +7,6 @@
 
 
 from selenium.webdriver import Remote
-from selenium import webdriver
-from loguru import logger
-from common.base_path import _dir
 from common import _read_yaml
 from weilaizz.templates.http_demo.downloadChromeDriver.downloadBrowser import get_chrome_driver
 
