@@ -6,8 +6,8 @@
 
 
 import os
-import globa
 import platform
+from env import globa
 from common.base_path import _dir
 from common.clean_f import clearLog as cl, clearFile as cf
 from shutil import copyfile
